===================
About tripleoclient
===================

General information
-------------------

**tripleoclient** is an OpenStackClient (OSC) plugin implementation that
implements commands useful for TripleO and the install and management of
both an undercloud and an overcloud.

See the
`TripleO Documentation <https://docs.openstack.org/tripleo-docs/latest/>`_
for details on using tripleoclient.

See the
`Release Notes <https://docs.openstack.org/releasenotes/python-tripleoclient>`_

Team and repository tags
------------------------

.. image:: https://governance.openstack.org/tc/badges/python-tripleoclient.svg
    :target: https://governance.openstack.org/tc/reference/tags/index.html
